@@ -4,12 +4,12 @@ use polars_core::prelude::*;
 use polars_utils::arena::Arena;
 
 use crate::prelude::*;
-use crate::utils::expr_to_root_column_names;
+use crate::utils::expr_to_leaf_column_names;
 
 impl Expr {
     /// Get a dot language representation of the Expression.
     #[cfg_attr(docsrs, doc(cfg(feature = "dot_diagram")))]
-    pub fn to_dot(&self) -> Result<String> {
+    pub fn to_dot(&self) -> PolarsResult<String> {
         let mut s = String::with_capacity(512);
         self.dot_viz(&mut s, (0, 0), "").expect("io error");
         s.push_str("\n}");
@@ -69,7 +69,7 @@ impl Expr {
 impl LazyFrame {
     /// Get a dot language representation of the LogicalPlan.
     #[cfg_attr(docsrs, doc(cfg(feature = "dot_diagram")))]
-    pub fn to_dot(&self, optimized: bool) -> Result<String> {
+    pub fn to_dot(&self, optimized: bool) -> PolarsResult<String> {
         let mut s = String::with_capacity(512);
 
         let mut logical_plan = self.clone().get_plan_builder().build();
@@ -176,11 +176,11 @@ impl LogicalPlan {
             AnonymousScan { schema, .. } => {
                 let total_columns = schema.len();
 
-                let current_node = format!("ANONYMOUS SCAN;\nπ {}", total_columns);
+                let fmt = format!("ANONYMOUS SCAN;\nπ {}", total_columns);
                 let current_node = DotNode {
                     branch,
                     id,
-                    fmt: &current_node,
+                    fmt: &fmt,
                 };
                 self.write_dot(acc_str, prev_node, current_node, id_map)
             }
@@ -200,11 +200,17 @@ impl LogicalPlan {
             Cache {
                 input,
                 id: cache_id,
+                count,
             } => {
+                let fmt = if *count == usize::MAX {
+                    "CACHE".to_string()
+                } else {
+                    format!("CACHE: {}times", *count)
+                };
                 let current_node = DotNode {
                     branch: *cache_id,
                     id: *cache_id,
-                    fmt: "CACHE",
+                    fmt: &fmt,
                 };
                 // here we take the cache id, to ensure the same cached subplans get the same ids
                 self.write_dot(acc_str, prev_node, current_node, id_map)?;
@@ -380,7 +386,7 @@ impl LogicalPlan {
                     if let Expr::Alias(_, name) = e {
                         write!(fmt, "\"{}\",", name)?
                     } else {
-                        for name in expr_to_root_column_names(e).iter().take(1) {
+                        for name in expr_to_leaf_column_names(e).iter().take(1) {
                             write!(fmt, "\"{}\",", name)?
                         }
                     }
@@ -439,12 +445,11 @@ impl LogicalPlan {
 
                 let pred = fmt_predicate(predicate.as_ref());
                 let fmt = format!(
-                    "PARQUET SCAN {};\nπ {}/{};\nσ {} [{:?}]",
+                    "PARQUET SCAN {};\nπ {}/{};\nσ {}",
                     path.to_string_lossy(),
                     n_columns,
                     total_columns,
                     pred,
-                    (branch, id)
                 );
                 let current_node = DotNode {
                     branch,
@@ -469,12 +474,11 @@ impl LogicalPlan {
 
                 let pred = fmt_predicate(predicate.as_ref());
                 let fmt = format!(
-                    "IPC SCAN {};\nπ {}/{};\nσ {} [{:?}]",
+                    "IPC SCAN {};\nπ {}/{};\nσ {}",
                     path.to_string_lossy(),
                     n_columns,
                     total_columns,
                     pred,
-                    (branch, id)
                 );
                 let current_node = DotNode {
                     branch,
@@ -502,8 +506,8 @@ impl LogicalPlan {
                     fmt: &fmt,
                 };
                 self.write_dot(acc_str, prev_node, current_node, id_map)?;
-                input_left.dot(acc_str, (branch + 10, id + 1), current_node, id_map)?;
-                input_right.dot(acc_str, (branch + 20, id + 1), current_node, id_map)
+                input_left.dot(acc_str, (branch + 100, id + 1), current_node, id_map)?;
+                input_right.dot(acc_str, (branch + 200, id + 1), current_node, id_map)
             }
             MapFunction {
                 input, function, ..
