@@ -10,11 +10,11 @@ pub struct SliceExec {
 }
 
 impl Executor for SliceExec {
-    fn execute(&mut self, state: &mut ExecutionState) -> Result<DataFrame> {
+    fn execute(&mut self, state: &mut ExecutionState) -> PolarsResult<DataFrame> {
         #[cfg(debug_assertions)]
         {
             if state.verbose() {
-                println!("run SciceExec")
+                println!("run SliceExec")
             }
         }
         let df = self.input.execute(state)?;
