@@ -22,12 +22,12 @@ use crate::prelude::*;
 /// Executors have other executors as input. By having a tree of executors we can execute the
 /// physical plan until the last executor is evaluated.
 pub trait Executor: Send + Sync {
-    fn execute(&mut self, cache: &mut ExecutionState) -> Result<DataFrame>;
+    fn execute(&mut self, cache: &mut ExecutionState) -> PolarsResult<DataFrame>;
 }
 
 pub struct Dummy {}
 impl Executor for Dummy {
-    fn execute(&mut self, _cache: &mut ExecutionState) -> Result<DataFrame> {
+    fn execute(&mut self, _cache: &mut ExecutionState) -> PolarsResult<DataFrame> {
         panic!("should not get here");
     }
 }
