@@ -10,7 +10,7 @@ pub trait SeriesMethods: SeriesSealed {
     fn value_counts(&self, multithreaded: bool, sorted: bool) -> PolarsResult<DataFrame> {
         let s = self.as_series();
         // we need to sort here as well in case of `maintain_order` because duplicates behavior is undefined
-        let groups = s.group_tuples(multithreaded, sorted);
+        let groups = s.group_tuples(multithreaded, sorted)?;
         let values = unsafe { s.agg_first(&groups) };
         let counts = groups.group_lengths("counts");
         let cols = vec![values.into_series(), counts.into_series()];
@@ -30,7 +30,7 @@ pub trait SeriesMethods: SeriesSealed {
                 let mut ca = s.list().unwrap().clone();
                 crate::chunked_array::hash::hash(&mut ca, build_hasher)
             }
-            _ => UInt64Chunked::from_vec(s.name(), s.0.vec_hash(build_hasher)),
+            _ => UInt64Chunked::from_vec(s.name(), s.0.vec_hash(build_hasher).unwrap()),
         }
     }
 }
