@@ -3,7 +3,7 @@ use std::fmt::{Debug, Formatter};
 use polars::prelude::PolarsError;
 use polars_core::error::ArrowError;
 use pyo3::create_exception;
-use pyo3::exceptions::{PyException, PyIOError, PyRuntimeError, PyValueError};
+use pyo3::exceptions::{PyException, PyIOError, PyRuntimeError};
 use pyo3::prelude::*;
 use thiserror::Error;
 
@@ -30,9 +30,11 @@ impl std::convert::From<PyPolarsErr> for PyErr {
                 PolarsError::ShapeMisMatch(err) => ShapeError::new_err(err.to_string()),
                 PolarsError::SchemaMisMatch(err) => SchemaError::new_err(err.to_string()),
                 PolarsError::Io(err) => PyIOError::new_err(err.to_string()),
-                PolarsError::InvalidOperation(err) => PyValueError::new_err(err.to_string()),
                 PolarsError::ArrowError(err) => ArrowErrorException::new_err(format!("{:?}", err)),
                 PolarsError::Duplicate(err) => DuplicateError::new_err(err.to_string()),
+                PolarsError::InvalidOperation(err) => {
+                    InvalidOperationError::new_err(err.to_string())
+                }
             },
             Arrow(err) => ArrowErrorException::new_err(format!("{:?}", err)),
             _ => default(),
@@ -58,3 +60,4 @@ create_exception!(exceptions, ArrowErrorException, PyException);
 create_exception!(exceptions, ShapeError, PyException);
 create_exception!(exceptions, SchemaError, PyException);
 create_exception!(exceptions, DuplicateError, PyException);
+create_exception!(exceptions, InvalidOperationError, PyException);
